==> foundation-2.0.3.tgz: package/lib/esm/Stack.js <==
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { css } from "@emotion/react";
import useTheme from "./useTheme";
import { forwardRef } from "react";
import { isNull, omit } from "lodash";
import Box from "./Box";
var alignments = {
    stretch: "stretch",
    left: "flex-start",
    right: "flex-end",
    center: "center",
};
var propsToOmit = ["d", "alignX", "css", "gap"];
export default forwardRef(function (props, ref) {
    var _a, _b;
    var s = useTheme().s;
    var dynamicStyles = {
        alignItems: alignments[(_a = props.alignX) !== null && _a !== void 0 ? _a : "stretch"],
    };
    if (!isNull(props.gap))
        dynamicStyles.rowGap = s[(_b = props.gap) !== null && _b !== void 0 ? _b : "md"];
    return (_jsx(Box, __assign({ d: "flex", css: css(css(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n          flex-direction: column;\n        "], ["\n          flex-direction: column;\n        "]))), dynamicStyles) }, omit(props, propsToOmit), { ref: ref })));
});
var templateObject_1;

==> foundation-2.3.2.tgz: package/lib/esm/Stack.js <==
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { css } from "@emotion/react";
import useTheme from "./useTheme";
import { forwardRef } from "react";
import { isNull, omit } from "lodash";
import Box from "./Box";
var alignments = {
    stretch: "stretch",
    left: "flex-start",
    right: "flex-end",
    center: "center",
};
var propsToOmit = ["d", "alignX", "css", "gap"];
var Stack = function (props, ref) {
    var _a, _b;
    var s = useTheme().s;
    var dynamicStyles = {
        alignItems: alignments[(_a = props.alignX) !== null && _a !== void 0 ? _a : "stretch"],
    };
    if (!isNull(props.gap))
        dynamicStyles.rowGap = s[(_b = props.gap) !== null && _b !== void 0 ? _b : "md"];
    return (_jsx(Box, __assign({ d: "flex", css: css(css(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n          flex-direction: column;\n        "], ["\n          flex-direction: column;\n        "]))), dynamicStyles) }, omit(props, propsToOmit), { ref: ref })));
};
export default forwardRef(Stack);
var templateObject_1;
